==> qtjambi-webenginecore-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiWebEngineCore/QWebEngineUrlRequestInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebengineurlrequestinfo.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>
#include <QtCore/qbytearray.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineUrlRequestInfo::block(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_block_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean shouldBlock0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::block(bool)", __qt_this)
        __qt_this->block(static_cast<bool>(shouldBlock0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineUrlRequestInfo::changed()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_changed_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::changed()const", __qt_this)
        __java_return_value = __qt_this->changed();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::firstPartyUrl()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_firstPartyUrl_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::firstPartyUrl()const", __qt_this)
        QUrl __qt_return_value = __qt_this->firstPartyUrl();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::initiator()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_initiator_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::initiator()const", __qt_this)
        QUrl __qt_return_value = __qt_this->initiator();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::navigationType()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_navigationType_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::navigationType()const", __qt_this)
        QWebEngineUrlRequestInfo::NavigationType __qt_return_value = __qt_this->navigationType();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::redirect(QUrl)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_redirect_1native_1cref_1QUrl__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID url0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::redirect(QUrl)", __qt_this)
        const QUrl& __qt_url0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(url0);
        __qt_this->redirect(__qt_url0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineUrlRequestInfo::requestMethod()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_requestMethod_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::requestMethod()const", __qt_this)
        QByteArray __qt_return_value = __qt_this->requestMethod();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::requestUrl()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_requestUrl_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::requestUrl()const", __qt_this)
        QUrl __qt_return_value = __qt_this->requestUrl();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::resourceType()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_resourceType_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::resourceType()const", __qt_this)
        QWebEngineUrlRequestInfo::ResourceType __qt_return_value = __qt_this->resourceType();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::setHttpHeader(QByteArray,QByteArray)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_setHttpHeader_1native_1cref_1QByteArray_1cref_1QByteArray__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID name0,
 QtJambiNativeID value1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::setHttpHeader(QByteArray,QByteArray)", __qt_this)
        const QByteArray& __qt_name0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(name0);
        const QByteArray& __qt_value1 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(value1);
        __qt_this->setHttpHeader(__qt_name0, __qt_value1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QWebEngineUrlRequestInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QWebEngineUrlRequestInfo>("QWebEngineUrlRequestInfo", "io/qt/webengine/core/QWebEngineUrlRequestInfo");
// BEGIN: function table
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids

    Q_UNUSED(typeId)

// BEGIN: enums and flags
    registerEnumTypeInfo<QWebEngineUrlRequestInfo::NavigationType>("QWebEngineUrlRequestInfo::NavigationType", "io/qt/webengine/core/QWebEngineUrlRequestInfo$NavigationType");
    registerEnumTypeInfo<QWebEngineUrlRequestInfo::ResourceType>("QWebEngineUrlRequestInfo::ResourceType", "io/qt/webengine/core/QWebEngineUrlRequestInfo$ResourceType");
// END: enums and flags
}

==> qtjambi-webenginecore-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiWebEngineCore/QWebEngineUrlRequestInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebengineurlrequestinfo.h>
#include <QtCore/QHash>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineUrlRequestInfo::block(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_block_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean shouldBlock0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::block(bool)", __qt_this)
        __qt_this->block(static_cast<bool>(shouldBlock0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineUrlRequestInfo::changed()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_changed_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::changed()const", __qt_this)
        __java_return_value = __qt_this->changed();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::firstPartyUrl()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_firstPartyUrl_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::firstPartyUrl()const", __qt_this)
        QUrl __qt_return_value = __qt_this->firstPartyUrl();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::httpHeaders()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_httpHeaders_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::httpHeaders()const", __qt_this)
        QHash<QByteArray, QByteArray> __qt_return_value = __qt_this->httpHeaders();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::initiator()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_initiator_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::initiator()const", __qt_this)
        QUrl __qt_return_value = __qt_this->initiator();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::navigationType()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_navigationType_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::navigationType()const", __qt_this)
        QWebEngineUrlRequestInfo::NavigationType __qt_return_value = __qt_this->navigationType();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::redirect(QUrl)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_redirect_1native_1cref_1QUrl__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID url0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::redirect(QUrl)", __qt_this)
        const QUrl& __qt_url0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(url0);
        __qt_this->redirect(__qt_url0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineUrlRequestInfo::requestMethod()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_requestMethod_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::requestMethod()const", __qt_this)
        QByteArray __qt_return_value = __qt_this->requestMethod();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::requestUrl()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_requestUrl_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::requestUrl()const", __qt_this)
        QUrl __qt_return_value = __qt_this->requestUrl();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::resourceType()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_resourceType_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::resourceType()const", __qt_this)
        QWebEngineUrlRequestInfo::ResourceType __qt_return_value = __qt_this->resourceType();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineUrlRequestInfo::setHttpHeader(QByteArray,QByteArray)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineUrlRequestInfo_setHttpHeader_1native_1cref_1QByteArray_1cref_1QByteArray__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID name0,
 QtJambiNativeID value1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineUrlRequestInfo *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineUrlRequestInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineUrlRequestInfo::setHttpHeader(QByteArray,QByteArray)", __qt_this)
        const QByteArray& __qt_name0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(name0);
        const QByteArray& __qt_value1 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(value1);
        __qt_this->setHttpHeader(__qt_name0, __qt_value1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QWebEngineUrlRequestInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QWebEngineUrlRequestInfo>("QWebEngineUrlRequestInfo", "io/qt/webengine/core/QWebEngineUrlRequestInfo");
// BEGIN: function table
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids

    Q_UNUSED(typeId)

// BEGIN: enums and flags
    registerEnumTypeInfo<QWebEngineUrlRequestInfo::NavigationType>("QWebEngineUrlRequestInfo::NavigationType", "io/qt/webengine/core/QWebEngineUrlRequestInfo$NavigationType");
    registerEnumTypeInfo<QWebEngineUrlRequestInfo::ResourceType>("QWebEngineUrlRequestInfo::ResourceType", "io/qt/webengine/core/QWebEngineUrlRequestInfo$ResourceType");
// END: enums and flags
}
